#!/bin/bash
# ******************************************************************************
# Script Name    : set_all_patch_blackouts.sh
# Creator        : K. Kriebisch, AMIS Services b.v., Nieuwegein (NL)
# Creation date  : 01-05-2020
# Purpose        : Script to create a bash script header to use as executable result log
#
# Usage          : set_all_patch_blackouts.sh
# Remarks        : script uses EMCLI and is the output of the sql-script
# 	          "Create_Monthly_Patch_Blackout_Script.sql", which determines
#                  the correct parameters of the create blackout commands for
#                  each group of target hosts.
#
# RDBMS versions : applicable to all Linux versions
#------------------------------------------------------------------------------\
# Revision record
# Date        Version  Author  Modification
# ----------  ------   ------  ------------------------------------------------\
# 01-05-2020  1.0      KK      Created
# 01-06-2020  1.1      KK      switch to Notification BLs
# 08-06-2020  1.2      KK      return to normal BLs
# 07-10-2020  1.3      KK      added BLs voor shadow groepen
# 08-10-2020  1.4      KK      logische fout bij toevoeging van shadow groepen
#******************************************************************************
#
export PATH=/usr/local/bin:$PATH
export ORACLE_SID=OMS
export ORAENV_ASK=NO

. oraenv
export PASSWD=$(grep ${ORACLE_SID} /home/oracle/.sec/.passwdP|cut -d':' -f3 )
emcli login -username=sysman -password=$PASSWD
emcli sync

# Deleting the ended/stopped blackouts van de vorige keer
#
# Als hier geen commandos vermeld worden, zijn de BLs mogelijkerwijs nog aktief
# en moeten eerst gecheckt en dan manuel verwijdert worden!

emcli delete_blackout -name="PT-02_05:30_BlackOut"
emcli delete_blackout -name="PT-02_08:00_BlackOut"
emcli delete_blackout -name="PT-02_10:00_BlackOut"
emcli delete_blackout -name="PT-02_15:00_BlackOut"
emcli delete_blackout -name="PT-02_18:00_BlackOut"
emcli delete_blackout -name="PT-03_05:00_BlackOut"
emcli delete_blackout -name="PT-03_08:00_BlackOut"
emcli delete_blackout -name="PT-03_10:00_BlackOut"
emcli delete_blackout -name="PT-03_18:00_BlackOut"
emcli delete_blackout -name="PT-09_17:00_BlackOut"
emcli delete_blackout -name="PT-09_21:00_BlackOut"
emcli delete_blackout -name="PT-11_17:00_BlackOut"
emcli delete_blackout -name="PT-12_02:00_BlackOut"
emcli delete_blackout -name="PT-12_15:30_BlackOut"
emcli delete_blackout -name="PT-12_17:00_BlackOut"
emcli delete_blackout -name="PT-15_03:00_BlackOut"
emcli delete_blackout -name="PT-15_15:30_BlackOut"
emcli delete_blackout -name="PT-15_17:00_BlackOut"
emcli delete_blackout -name="PT-16_03:00_BlackOut"
emcli delete_blackout -name="PTS-02_05:30_BlackOut"
emcli delete_blackout -name="PTS-02_08:00_BlackOut"
emcli delete_blackout -name="PTS-02_10:00_BlackOut"
emcli delete_blackout -name="PTS-02_18:00_BlackOut"
emcli delete_blackout -name="PTS-03_05:00_BlackOut"
emcli delete_blackout -name="PTS-03_10:00_BlackOut"
emcli delete_blackout -name="PTS-12_15:30_BlackOut"
emcli delete_blackout -name="PTS-12_17:00_BlackOut"
emcli delete_blackout -name="PTS-15_03:00_BlackOut"
emcli delete_blackout -name="PTS-15_15:30_BlackOut"
emcli delete_blackout -name="PTS-15_17:00_BlackOut"
emcli delete_blackout -name="PTS-16_03:00_BlackOut"
emcli sync

# Creating EMCLI-commands for all PT-groups
#
# De starttijd is default op 15 min. voor de PRP-tijd gezet,
# en de duur van het blackout is default 120 minuten.
# Svp. Parameter Min_voor en/of Duur aan het begin van dit script
# aanpassen als Oracle voor het OS gepatched zal worden en
# voor- of achteraf meer tijd nodig is.

# PatchTuesday is deze maand: 2020-11-10

emcli create_blackout -name="PT-02_05:30_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PT-02_05:30:group" -schedule="frequency:once;start_time:2020-11-12 05:15;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PT-02_08:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PT-02_08:00:group" -schedule="frequency:once;start_time:2020-11-12 07:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PT-02_10:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PT-02_10:00:group" -schedule="frequency:once;start_time:2020-11-12 09:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PT-02_15:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PT-02_15:00:group" -schedule="frequency:once;start_time:2020-11-12 14:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PT-02_18:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PT-02_18:00:group" -schedule="frequency:once;start_time:2020-11-12 17:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PT-03_05:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PT-03_05:00:group" -schedule="frequency:once;start_time:2020-11-13 04:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PT-03_08:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PT-03_08:00:group" -schedule="frequency:once;start_time:2020-11-13 07:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PT-03_10:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PT-03_10:00:group" -schedule="frequency:once;start_time:2020-11-13 09:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PT-03_18:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PT-03_18:00:group" -schedule="frequency:once;start_time:2020-11-13 17:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PT-09_17:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PT-09_17:00:group" -schedule="frequency:once;start_time:2020-11-19 16:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PT-09_21:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PT-09_21:00:group" -schedule="frequency:once;start_time:2020-11-19 20:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PT-11_17:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PT-11_17:00:group" -schedule="frequency:once;start_time:2020-11-21 16:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PT-12_02:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PT-12_02:00:group" -schedule="frequency:once;start_time:2020-11-22 01:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PT-12_15:30_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PT-12_15:30:group" -schedule="frequency:once;start_time:2020-11-22 15:15;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PT-12_17:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PT-12_17:00:group" -schedule="frequency:once;start_time:2020-11-22 16:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PT-15_03:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PT-15_03:00:group" -schedule="frequency:once;start_time:2020-11-25 02:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PT-15_15:30_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PT-15_15:30:group" -schedule="frequency:once;start_time:2020-11-25 15:15;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PT-15_17:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PT-15_17:00:group" -schedule="frequency:once;start_time:2020-11-25 16:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PT-16_03:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PT-16_03:00:group" -schedule="frequency:once;start_time:2020-11-26 02:45;duration::120" -full_blackout_all_hosts  -jobs_allowed

#  *** Creating Blackouts for the Shadow Groups (PTS-) ***

emcli create_blackout -name="PTS-02_05:30_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PTS-02_05:30:group" -schedule="frequency:once;start_time:2020-11-12 05:15;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PTS-02_08:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PTS-02_08:00:group" -schedule="frequency:once;start_time:2020-11-12 07:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PTS-02_10:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PTS-02_10:00:group" -schedule="frequency:once;start_time:2020-11-12 09:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PTS-02_18:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PTS-02_18:00:group" -schedule="frequency:once;start_time:2020-11-12 17:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PTS-03_05:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PTS-03_05:00:group" -schedule="frequency:once;start_time:2020-11-13 04:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PTS-03_10:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PTS-03_10:00:group" -schedule="frequency:once;start_time:2020-11-13 09:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PTS-12_15:30_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PTS-12_15:30:group" -schedule="frequency:once;start_time:2020-11-22 15:15;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PTS-12_17:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PTS-12_17:00:group" -schedule="frequency:once;start_time:2020-11-22 16:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PTS-15_03:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PTS-15_03:00:group" -schedule="frequency:once;start_time:2020-11-25 02:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PTS-15_15:30_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PTS-15_15:30:group" -schedule="frequency:once;start_time:2020-11-25 15:15;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PTS-15_17:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PTS-15_17:00:group" -schedule="frequency:once;start_time:2020-11-25 16:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli create_blackout -name="PTS-16_03:00_BlackOut" -reason="OS Patch/Maintenance" -add_targets="PTS-16_03:00:group" -schedule="frequency:once;start_time:2020-11-26 02:45;duration::120" -full_blackout_all_hosts  -jobs_allowed
emcli sync
emcli logout
